function displayVelocityField(vx, vy, step, xfoe, yfoe)
% displayVelocityField(vx, vy, step, xfoe, yfoe)
% displays velocity vectors at equally spaced points, separated by step,
% along with a red dot at the location of the FOE

[xdim, ydim] = size(vx);
num = (xdim/step+1) * (ydim/step+1);      % total number of points where
points = zeros(step, num);                   % velocity is displayed
index = 1;  
for j = 1:step:ydim                % collect x, y, vx, vy for points where
    for i = 1:step:xdim                 % velocity is to be displayed
        points(1, index) = i;
        points(2, index) = j;
        points(3, index) = vx(i,j);
        points(4, index) = vy(i,j);
        index = index + 1;
    end
end
% display final velocity vectors
quiver(points(1,:), points(2,:), points(3,:), points(4,:), 0);
if (nargin > 3)
    hold on
    scatter(xfoe, yfoe, 100, 'r', 'filled')     % display FOE
end
set(gca, 'XTick', 0:20:200, 'YTick', 0:20:200, 'XTickLabel', -5:5, 'YTickLabel', -5:5)
axis([-10 210 -10 210])
hold off
