function [vx, vy, xfoe, yfoe] = setupImageVelocities(Tx, Ty, Tz, Rx, Ry, Rz, zmap)
% [vx, vy, xfoe, yfoe] = setupImageVelocities(Tx, Ty, Tz, Rx, Ry, Rz, zmap)
% creates matrices with x and y components of 2D velocity, given input
% parameters of observer motion and depth map. also returns the coordinates
% of the true FOE in (xfoe, yfoe)

[xdim, ydim] = size(zmap);
vx = zeros(xdim,ydim);
vy = zeros(xdim,ydim);
% matrix coordinates are scaled to determine simulated x,y coordinates
scale = 0.05;
xcenter = xdim/2;
ycenter = ydim/2;
for x = 1:xdim
    for y = 1:ydim
        % get x,y image coordinates and depth at this location
        xc = (x-xcenter)*scale;
        yc = (y-ycenter)*scale;
        zc = zmap(x,y);
        % equations for image velocities
        vx(x,y) = (xc*Tz-Tx)/zc + (Rx*xc*yc) - (Ry*(xc^2+1)) + (Rz*yc);
        vy(x,y) = (yc*Tz-Ty)/zc + (Rx*(yc^2+1)) - (Ry*xc*yc) - (Rz*xc);
    end
end
% if there is a forward motion component, compute the FOE
if (Tz ~= 0)
    xfoe = Tx/Tz;
    yfoe = Ty/Tz;
else
    xfoe = 1000.0;
    yfoe = 1000.0;
end