% getVideoImages.m
% script for reading in a video sequence of a traffic scene and 
% extracting three image frames from the video

% load the sequence.mpg video file into a structure named traffic and
% create simple variables to store values from fields of the structure
traffic = VideoReader('sequence.mpg');
nFrames = traffic.NumberOfFrames;
height = traffic.Height;
width = traffic.Width;

% create a vector of structures that each have two fields named cdata
% and colormap. The value of each cdata field is initially set to a
% matrix of zeros, and the colormap is set to an empty vector
mov(1:nFrames) = struct('cdata', zeros(height, width, 3, 'uint8'), ...
                        'colormap', []);

% read the individual video frames into the cdata fields in the mov vector
for k = 1:nFrames
    mov(k).cdata = read(traffic, k);
end

% open a new figure window and show the movie
movFig = figure;
movie(movFig, mov, 1, traffic.FrameRate); 

% create gray-level images of type double, from three frames of the video
im1 = double(rgb2gray(mov(1).cdata));
im1(480:512, 250:512) = 0;          % remove clock in bottom right corner
im2 = double(rgb2gray(mov(5).cdata));
im2(480:512, 250:512) = 0;
im3 = double(rgb2gray(mov(9).cdata));
im3(480:512, 250:512) = 0;
imtool(im1, [], 'InitialMagnification', 'fit')  % display first image

% show movie of the three images in a new figure window
altFig = figure('Position', [600 200 width height]);
for i = 1:5
    imshow(im1, [], 'InitialMagnification', 'fit')
    pause(1)
    imshow(im2, [], 'InitialMagnification', 'fit')
    pause(1)
    imshow(im3, [], 'InitialMagnification', 'fit')
    pause(1)
    imshow(im2, [], 'InitialMagnification', 'fit')
    pause(1)
end

